"use strict";

var _chunkQKLU3LNTcjs = require('../../chunk-QKLU3LNT.cjs');
require('../../chunk-J2UQ7CEL.cjs');
require('../../chunk-BQ6MKKYS.cjs');
require('../../chunk-4B2XCWGL.cjs');
require('../../chunk-5CIFX7O6.cjs');
require('../../chunk-ON3N7H7T.cjs');
require('../../chunk-XC7SHABV.cjs');
require('../../chunk-ABEJKCAO.cjs');
require('../../chunk-6TCZFTKD.cjs');
require('../../chunk-U7QCFBCQ.cjs');
require('../../chunk-UKD65B23.cjs');
require('../../chunk-TJP5RDJE.cjs');
require('../../chunk-J42M6DF3.cjs');
require('../../chunk-N46W55MH.cjs');
require('../../chunk-L646RZQB.cjs');
require('../../chunk-ZYPCVNSG.cjs');
require('../../chunk-XV5FJ2SJ.cjs');
require('../../chunk-A4VFMLAN.cjs');
require('../../chunk-RZKLDILW.cjs');
require('../../chunk-DRTH56G4.cjs');
require('../../chunk-RKOTNV3K.cjs');
require('../../chunk-XWE2OTGL.cjs');
require('../../chunk-KTC5RW57.cjs');
require('../../chunk-GU6AYGWK.cjs');
require('../../chunk-SNRM7OTJ.cjs');
require('../../chunk-ZGKV237Z.cjs');
require('../../chunk-NTCZ6VPJ.cjs');
require('../../chunk-N7OUNPMM.cjs');
require('../../chunk-MPD2DJAD.cjs');
require('../../chunk-YELWQAMG.cjs');
require('../../chunk-XVQVWCIE.cjs');
require('../../chunk-52BL3727.cjs');
require('../../chunk-FEYF6QXS.cjs');
require('../../chunk-JQSCYOKH.cjs');
require('../../chunk-L5SJIWCK.cjs');
require('../../chunk-EE5CB3R7.cjs');


var _chunkQYCE2TUJcjs = require('../../chunk-QYCE2TUJ.cjs');
require('../../chunk-5KIDARFB.cjs');
require('../../chunk-CEXYDYSH.cjs');
require('../../chunk-PJXRDQ2A.cjs');
require('../../chunk-6T6PI6XG.cjs');
require('../../chunk-37LFQPGN.cjs');
require('../../chunk-FYLSPYV2.cjs');
require('../../chunk-YKRFYR2Q.cjs');
require('../../chunk-7FO3T7KH.cjs');
require('../../chunk-BMRI2X66.cjs');
require('../../chunk-QP5Y3I6F.cjs');
require('../../chunk-TAKWLGAZ.cjs');

// src/common/exec/queue.spec.ts
describe("queue", () => {
  it("should execute in strict order", async () => {
    expect.assertions(1);
    const list = [];
    const queue = new (0, _chunkQKLU3LNTcjs.SerialQueue)();
    void queue.enqueue(async () => {
      await _chunkQYCE2TUJcjs.sleep.call(void 0, 100);
      list.push("a");
    });
    void queue.enqueue(async () => {
      await _chunkQYCE2TUJcjs.sleep.call(void 0, 200);
      list.push("b");
    });
    void queue.enqueue(async () => {
      await _chunkQYCE2TUJcjs.sleep.call(void 0, 1);
      list.push("c");
    });
    await queue.wait();
    expect(list).toEqual(["a", "b", "c"]);
  });
  it("should execute in random order", async () => {
    expect.assertions(1);
    const list = [];
    void (async () => {
      await _chunkQYCE2TUJcjs.sleep.call(void 0, 100);
      list.push("a");
    })();
    void (async () => {
      await _chunkQYCE2TUJcjs.sleep.call(void 0, 200);
      list.push("b");
    })();
    void (async () => {
      await _chunkQYCE2TUJcjs.sleep.call(void 0, 1);
      list.push("c");
    })();
    await _chunkQYCE2TUJcjs.sleep.call(void 0, 500);
    expect(list).toEqual(["c", "a", "b"]);
  });
  it("should return value", async () => {
    expect.assertions(2);
    const list = [];
    const queue = new (0, _chunkQKLU3LNTcjs.SerialQueue)();
    void queue.enqueue(async () => {
      await _chunkQYCE2TUJcjs.sleep.call(void 0, 100);
      list.push("a");
    });
    const r = await queue.enqueue(async () => {
      await _chunkQYCE2TUJcjs.sleep.call(void 0, 200);
      list.push("b");
      return 123;
    });
    expect(r).toEqual(123);
    expect(list).toEqual(["a", "b"]);
    await queue.wait();
  });
  it("should pause", async () => {
    expect.assertions(3);
    const list = [];
    const queue = new (0, _chunkQKLU3LNTcjs.SerialQueue)();
    const events = [];
    queue.onAny((...args) => events.push(args));
    void queue.enqueue(async () => {
      await _chunkQYCE2TUJcjs.sleep.call(void 0, 100);
      list.push("a");
    });
    void queue.enqueue(async () => {
      await _chunkQYCE2TUJcjs.sleep.call(void 0, 200);
      list.push("b");
    });
    void queue.enqueue(async () => {
      await _chunkQYCE2TUJcjs.sleep.call(void 0, 1);
      list.push("c");
    });
    await queue.pause();
    expect(list).toEqual(["a"]);
    queue.resume();
    await queue.wait();
    expect(list).toEqual(["a", "b", "c"]);
    expect(events).toMatchInlineSnapshot(`
      Array [
        Array [
          "didUpdate",
          1,
          0,
        ],
        Array [
          "didStart",
          1,
        ],
        Array [
          "didUpdate",
          2,
          0,
        ],
        Array [
          "didUpdate",
          3,
          0,
        ],
        Array [
          "didUpdate",
          3,
          1,
        ],
        Array [
          "didUpdate",
          3,
          2,
        ],
        Array [
          "didUpdate",
          3,
          3,
        ],
        Array [
          "didFinish",
        ],
      ]
    `);
  });
  it("should cancel the rest", async () => {
    expect.assertions(3);
    const list = [];
    const queue = new (0, _chunkQKLU3LNTcjs.SerialQueue)();
    const events = [];
    queue.onAny((...args) => events.push(args));
    await queue.pause();
    void queue.enqueue(async () => {
      await _chunkQYCE2TUJcjs.sleep.call(void 0, 100);
      list.push("a");
    });
    void queue.enqueue(async () => {
      await _chunkQYCE2TUJcjs.sleep.call(void 0, 200);
      list.push("b");
    });
    void queue.enqueue(async () => {
      await _chunkQYCE2TUJcjs.sleep.call(void 0, 1);
      list.push("c");
    }).then((r) => {
      expect(r).toBe(void 0);
    });
    await queue.cancelAll();
    queue.resume();
    await queue.wait();
    expect(list).toEqual([]);
    expect(events).toMatchInlineSnapshot(`
      Array [
        Array [
          "didUpdate",
          1,
          0,
        ],
        Array [
          "didUpdate",
          2,
          0,
        ],
        Array [
          "didUpdate",
          3,
          0,
        ],
        Array [
          "didCancel",
        ],
        Array [
          "didFinish",
        ],
      ]
    `);
  });
});
//# sourceMappingURL=queue.spec.cjs.map