import {
  filesAsync,
  getFingerprintAsync,
  getStatAsync
} from "../chunk-5T734HLH.js";
import "../chunk-EGXUCKU4.js";
import "../chunk-X54PUZTY.js";
import "../chunk-HMRSQHLY.js";
import "../chunk-UMUHNSGZ.js";
import "../chunk-3ESD64QY.js";
import "../chunk-AZMPILEB.js";
import "../chunk-MO24G7VK.js";
import "../chunk-QQSABUQG.js";
import "../chunk-RNL46FQ3.js";
import "../chunk-MWUFUBY5.js";
import "../chunk-GKKLBSFA.js";
import "../chunk-264HKVNG.js";
import "../chunk-BSY5YJFG.js";
import "../chunk-LKHGPAZI.js";
import "../chunk-FLFB2K34.js";
import "../chunk-HST4VI64.js";
import "../chunk-A7SUGWC3.js";
import "../chunk-2A3BQWES.js";
import "../chunk-B44DP4LU.js";
import "../chunk-XSWQ6RVX.js";
import "../chunk-3VW55L2O.js";
import "../chunk-2QDXP3IF.js";
import "../chunk-HA36NND2.js";
import "../chunk-YFNV56TG.js";
import "../chunk-FVRBXAI3.js";
import "../chunk-STU7RCYM.js";
import "../chunk-27SEBYZU.js";
import "../chunk-2Y2HLBOR.js";
import "../chunk-MPAXUMZ5.js";
import "../chunk-PJDBG5VS.js";
import "../chunk-3SV2JDUK.js";
import "../chunk-RVLBQKTB.js";
import "../chunk-USM6V6GH.js";
import "../chunk-TSCDX4AS.js";
import "../chunk-D6B6MYVG.js";
import "../chunk-BK3LMOUU.js";
import "../chunk-A526SGYQ.js";
import "../chunk-PJAUZ5BZ.js";
import "../chunk-6OKCPP4P.js";
import "../chunk-7IUVQQ4S.js";
import "../chunk-MIZOLME5.js";
import "../chunk-W5QDNVYF.js";
import "../chunk-YX6CL4KH.js";
import "../chunk-I45WP5PM.js";
import "../chunk-ZFRTRIT4.js";
import "../chunk-CFICINSP.js";
import "../chunk-6C3JJJOL.js";
import "../chunk-5Y3HYG6B.js";
import "../chunk-FPJHSFML.js";
import "../chunk-XSB2WAW2.js";
import "../chunk-X2DIUKLP.js";
import "../chunk-NYCGHEIN.js";
import "../chunk-AS5LR4AI.js";
import "../chunk-KQSQJAHU.js";
import "../chunk-JC22THP7.js";
import "../chunk-2HWPZ6ZE.js";
import "../chunk-ZJ56YG7L.js";
import "../chunk-73CVRDI7.js";
import "../chunk-FL5CT6MC.js";
import "../chunk-HLRQ5H3N.js";
import "../chunk-DXSTF7NX.js";
import "../chunk-AY5LGXTC.js";
import "../chunk-DGP32WEQ.js";
import "../chunk-N5R4OMJA.js";
import "../chunk-SOTGICOC.js";
import "../chunk-MVRB7Y7X.js";
import "../chunk-FSDCRQB3.js";
import "../chunk-MRFHKDNG.js";
import "../chunk-AEBHR4XF.js";
import "../chunk-IZT6OHMS.js";
import "../chunk-GY34N3KU.js";
import "../chunk-I7E3FVGN.js";
import "../chunk-TYWNSO7K.js";
import "../chunk-ZMFW3O35.js";
import "../chunk-5BQNKE5C.js";
import "../chunk-7NSVDPHN.js";
import "../chunk-WG6ZJDFQ.js";
import "../chunk-VWBTJP5F.js";

// src/node/files-async.spec.ts
describe("getStatAsync", () => {
  it("should return the stat object for a valid path", async () => {
    const path = __filename;
    const statObject = await getStatAsync(path);
    expect(statObject).toBeDefined();
    expect(statObject.isFile()).toBe(true);
  });
  it("should return undefined for an invalid path", async () => {
    const path = "/invalid/path";
    const statObject = await getStatAsync(path);
    expect(statObject).toBeUndefined();
  });
  it("should return the fingerprint for a valid path", async () => {
    const path = __filename;
    const fingerprint = await getFingerprintAsync(path);
    expect(fingerprint).toBeDefined();
    expect(typeof fingerprint).toBe("string");
  });
  it("should return undefined for an invalid path 2", async () => {
    const path = "/invalid/path";
    const fingerprint = await getFingerprintAsync(path);
    expect(fingerprint).toBeUndefined();
  });
  it("should return an array of file paths", async () => {
    const paths = await filesAsync({ basePath: __dirname });
    expect(Array.isArray(paths)).toBe(true);
    expect(paths.length).toBeGreaterThan(0);
    expect(typeof paths[0]).toBe("string");
  });
  it("should return an array of file paths matching the pattern", async () => {
    const pattern = "*.ts";
    const paths = await filesAsync({ basePath: __dirname, pattern });
    expect(Array.isArray(paths)).toBe(true);
    expect(paths.length).toBeGreaterThan(0);
    expect(typeof paths[0]).toBe("string");
    expect(paths.every((path) => path.endsWith(".ts"))).toBe(true);
  });
  it("should return an empty array if no files match the pattern", async () => {
    const pattern = "*.docx";
    const paths = await filesAsync({ basePath: __dirname, pattern });
    expect(Array.isArray(paths)).toBe(true);
    expect(paths.length).toBe(0);
  });
  it("should return an array of file paths filtered by the custom filter function", async () => {
    const filter = (name) => name.includes("spec");
    const paths = await filesAsync({ basePath: __dirname, filter });
    expect(Array.isArray(paths)).toBe(true);
    expect(paths.length).toBeGreaterThan(0);
    expect(typeof paths[0]).toBe("string");
    expect(paths.every((path) => path.includes("spec"))).toBe(true);
  });
  it("should return an empty array if no files pass the custom filter function", async () => {
    const filter = (name) => name.includes("xyz");
    const paths = await filesAsync({ basePath: __dirname, filter });
    expect(Array.isArray(paths)).toBe(true);
    expect(paths.length).toBe(0);
  });
  it("should ignore hidden files by default", async () => {
    const paths = await filesAsync({ basePath: __dirname });
    expect(Array.isArray(paths)).toBe(true);
    expect(paths.every((path) => !path.includes("/."))).toBe(true);
  });
});
//# sourceMappingURL=files-async.spec.js.map